@@ -138,11 +138,16 @@ nitpick_ignore = [('py:obj', 'glue.viewers.common.qt.toolbar.BasicToolbar.insert
                   ('py:class', 'glue.viewers.image.layer_artist.ImageLayerBase'),
                   ('py:class', 'glue.viewers.image.layer_artist.RGBImageLayerBase'),
                   ('py:class', 'glue.viewers.image.state.BaseImageLayerState'),
+                  ('py:class', 'glue.viewers.common.qt.toolbar.BasicToolbar'),
+                  ('py:class', 'glue.viewers.common.qt.base_widget.BaseQtViewerWidget'),
                   ('py:class', 'sip.voidptr'),
-                  ('py:class', 'PyQt5.sip.voidptr')]
+                  ('py:class', 'PyQt5.sip.voidptr'),
+                  ('py:class', 'PYQT_SLOT')]
 
 nitpick_ignore_regex = [('py:class', r'PyQt5\.QtCore\.Q[A-Z][a-zA-Z]+'),
                         ('py:class', r'PyQt5\.QtWidgets\.Q[A-Z][a-zA-Z]+'),
+                        ('py:class', r'PyQt6\.QtCore\.Q[A-Z][a-zA-Z]+'),
+                        ('py:class', r'PyQt6\.QtWidgets\.Q[A-Z][a-zA-Z]+'),
                         ('py:class', r'Qt\.[A-Z][a-zA-Z]+'),
                         ('py:class', r'QPalette\.[A-Z][a-zA-Z]+'),
                         ('py:class', r'QWidget\.[A-Z][a-zA-Z]+'),
