@@ -14,8 +14,8 @@ from glue.core.message import SubsetDeleteMessage, SubsetUpdateMessage
 from glue.core.decorators import memoize
 from glue.core.visual import VisualAttributes
 from glue.config import settings
-from glue.utils import (view_shape, broadcast_to, floodfill, combine_slices,
-                        polygon_line_intersections, categorical_ndarray, iterate_chunks)
+from glue.utils import (categorical_ndarray, combine_slices, floodfill, iterate_chunks,
+                        polygon_line_intersections, view_shape)
 
 
 __all__ = ['Subset', 'SubsetState', 'RoiSubsetStateNd', 'RoiSubsetState', 'CategoricalROISubsetState',
@@ -458,7 +458,7 @@ class SubsetState(object):
             Any object that returns a valid view for a Numpy array.
         """
         shp = view_shape(data.shape, view)
-        return broadcast_to(False, shp)
+        return np.broadcast_to(False, shp)
 
     @contract(returns='isinstance(SubsetState)')
     def copy(self):
@@ -1327,7 +1327,7 @@ class SliceSubsetState(SubsetState):
 
             if order is None:
                 # We use broadcast_to for minimal memory usage
-                return broadcast_to(False, shape)
+                return np.broadcast_to(False, shape)
             else:
                 # Reorder slices
                 slices = [self.slices[idx] for idx in order]
@@ -1350,7 +1350,7 @@ class SliceSubsetState(SubsetState):
                 elif np.isscalar(view[i]):
                     beg, end, stp = slices[i].indices(data.shape[i])
                     if view[i] < beg or view[i] >= end or (view[i] - beg) % stp != 0:
-                        return broadcast_to(False, shape)
+                        return np.broadcast_to(False, shape)
                 elif isinstance(view[i], slice):
                     if view[i].step is not None and view[i].step < 0:
                         beg, end, step = view[i].indices(data.shape[i])
