@@ -225,7 +225,7 @@ class CompositeArray(object):
 
     @property
     def size(self):
-        return np.product(self.shape)
+        return np.prod(self.shape)
 
     def __contains__(self, item):
         return item in self.layers
